#
# spec file for package gf2x
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gf2x
%define lname	libgf2x3
Version:        1.3.0
Release:        3.5
Summary:        Library for multiplication over the GF(2) field
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gitlab.inria.fr/gf2x/gf2x
Source:         https://gitlab.inria.fr/gf2x/gf2x/uploads/c46b1047ba841c20d1225ae73ad6e4cd/gf2x-1.3.0.tar.gz
Patch1:         gcc14.patch
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config

%description
gf2x is a library for multiplication of polynomials over the
GF(2) binary field.

%package -n %lname
Summary:        Library for multiplication over the GF(2) field
Group:          System/Libraries

%description -n %lname
gf2x is a library for multiplication of polynomials over the
GF(2) binary field.

%package devel
Summary:        Development headers for libgf2x
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
gf2x is a library for fast multiplication of polynomials over the
GF(2) binary field.

This package contains the interface definitions for the gf2x library.

%prep
%autosetup -p1

%build
autoreconf -fi
# SSE2 may not be available on all x86_32 machines.
# PCLMUL may not be available on all machines.
%configure --disable-static \
%ifarch %ix86
	--disable-sse2 \
%endif
	--disable-pclmul \
	--enable-fft-interface
%make_build

%check
%make_build check

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libgf2x.so.*
%_libdir/libgf2x-fft.so.*
%license COPYING

%files devel
%_includedir/gf2x*
%_libdir/libgf2x.so
%_libdir/libgf2x-fft.so
%_libdir/pkgconfig/*.pc

%changelog
* Wed Aug 21 2024 Jan Engelhardt <jengelh@inai.de>
- Add gcc14.patch
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update homepage URL and build recipe.
* Mon Dec 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3
  * gf2x.h now contains GF2X_VERSION_* macros
  * Split off the FFT code into libgf2x-fft.
  * The FFT interface api has been significantly modified and
    improved. A new interface for computing middle products has
    been added. The C++ wrapper code has been improved (no longer
    a macro).
- Drop 0001-build-fix-version-info-for-libgf2x-after-ABI-break.patch
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Specfile modernizations.
* Mon Apr 30 2018 jengelh@inai.de
- Ensure neutrality of description.
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 1.2
  * No user changelog available
- Remove gf2x-memset.diff (fixed upstream)
- Add 0001-build-fix-version-info-for-libgf2x-after-ABI-break.patch
* Fri Jun 26 2015 jengelh@inai.de
- Disable SSE2 on x86 because it is not necessarily present
- Add gf2x-memset.diff
* Thu Nov 29 2012 jengelh@inai.de
- Update to new upstream release 1.1
  * trap bad arguments to gf2x_tfft_init
* Thu Sep 15 2011 jengelh@medozas.de
- Initial package (version 1.0) for build.opensuse.org
